==> material_google_fonts_choosers-0.0.1.tar.gz: lib/src/material_google_fonts_search_input.dart <==
library google_fonts_search_input;

import 'package:flutter/material.dart';

class FontSearchInput extends StatefulWidget {
  final List<String> fontList;

  int threshold = 3;
  InputDecoration inputDecoration = InputDecoration(
      hintText: 'Start typing....', helperText: 'Search for a better font');
  final Function confirm;

  FontSearchInput(
      {this.fontList, this.threshold, this.confirm, this.inputDecoration});
  @override
  _FontSearchInputState createState() => _FontSearchInputState();
}

class _FontSearchInputState extends State<FontSearchInput> {
  String currentSearchMatch = "No matches";
  String currentValue = "Search for a better font";

  _FontSearchInputState();

//Search the Google Fonts API

  int searchGoogleFonts(String value) {
    // TODO set up a debounce
    // We are going to call [fonts.google.com] after 3 chars
    // search fonts list to see if we have a match.
    if (value.length > widget.threshold) {
      return widget.fontList.indexWhere((s) => s.contains(value));
    }
  }

  updateCurrentSearchMatch(int index) {
    setState(() {
      currentSearchMatch = widget.fontList[index];
    });
  }

  //Comment this out before release so they have to create thier own confirmation logic. I want ot keep this agnostic

  onChanged(String value) => searchGoogleFonts(value);

  //A basic input widget
  //So you can style it as you need
  input(decoration) => TextField(decoration: decoration, onChanged: onChanged);

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width * 0.6;
    return Container(
      width: width,
      child: Column(
        children: <Widget>[
          input(widget.inputDecoration),
          FlatButton(
              child: Text(currentSearchMatch), onPressed: widget.confirm),
        ],
      ),
    );
  }
}

/// A Calculator.
class GoogleFontProvider {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}

==> material_google_fonts_choosers-0.0.2.tar.gz: lib/src/material_google_fonts_search_input.dart <==
library material_google_fonts_search_input;

import 'package:flutter/material.dart';

class MaterialGoogleFontSearchInput extends StatefulWidget {
  final List<String> fontList;

  final InputDecoration inputDecoration;
  final Function confirm;

  MaterialGoogleFontSearchInput(
      {this.fontList, this.confirm, this.inputDecoration});
  @override
  _MaterialGoogleFontSearchInputState createState() =>
      _MaterialGoogleFontSearchInputState();
}

class _MaterialGoogleFontSearchInputState
    extends State<MaterialGoogleFontSearchInput> {
  String currentSearchMatch = "No matches";
  String currentValue = "Search for a better font";
  int threshold = 3;

  _MaterialGoogleFontSearchInputState();

//Search the Google Fonts API

  int searchGoogleFonts(String value) {
    // TODO set up a debounce
    // We are going to call [fonts.google.com] after 3 chars
    // search fonts list to see if we have a match.
    if (value.length > threshold) {
      return widget.fontList.indexWhere((s) => s.contains(value));
    }
  }

  updateCurrentSearchMatch(int index) {
    setState(() {
      currentSearchMatch = widget.fontList[index];
    });
  }

  //Comment this out before release so they have to create thier own confirmation logic. I want ot keep this agnostic

  onChanged(String value) => searchGoogleFonts(value);

  //A basic input widget
  //So you can style it as you need
  input(decoration) => TextField(decoration: decoration, onChanged: onChanged);

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width * 0.6;
    return Container(
      width: width,
      child: Column(
        children: <Widget>[
          input(widget.inputDecoration),
          FlatButton(
              child: Text(currentSearchMatch), onPressed: widget.confirm),
        ],
      ),
    );
  }
}

/// A Calculator.
class GoogleFontProvider {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}
